You can subscribe to this list here.
| 2005 |
Jan
|
Feb
|
Mar
(41) |
Apr
(9) |
May
|
Jun
|
Jul
(39) |
Aug
(38) |
Sep
(135) |
Oct
(220) |
Nov
(75) |
Dec
(74) |
|---|---|---|---|---|---|---|---|---|---|---|---|---|
| 2006 |
Jan
(44) |
Feb
(160) |
Mar
(49) |
Apr
(69) |
May
(40) |
Jun
(52) |
Jul
(47) |
Aug
(51) |
Sep
(19) |
Oct
(22) |
Nov
(36) |
Dec
(76) |
| 2007 |
Jan
(154) |
Feb
(165) |
Mar
(186) |
Apr
(143) |
May
(175) |
Jun
(133) |
Jul
(203) |
Aug
(177) |
Sep
(136) |
Oct
|
Nov
|
Dec
|
|
From: <caw...@us...> - 2007-04-30 14:09:45
|
Revision: 2397
http://svn.sourceforge.net/rubyeclipse/?rev=2397&view=rev
Author: cawilliams
Date: 2007-04-30 07:09:45 -0700 (Mon, 30 Apr 2007)
Log Message:
-----------
add methods to grab RI or RDoc locations (based on default VM install location)
Modified Paths:
--------------
trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/launching/RubyRuntime.java
Modified: trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/launching/RubyRuntime.java
===================================================================
--- trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/launching/RubyRuntime.java 2007-04-30 14:08:47 UTC (rev 2396)
+++ trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/launching/RubyRuntime.java 2007-04-30 14:09:45 UTC (rev 2397)
@@ -1657,4 +1657,23 @@
notifyDefaultVMChanged(previous, current);
}
}
+
+ public static File getRI() {
+ return getBinExecutable("ri");
+ }
+
+ public static File getRDoc() {
+ return getBinExecutable("rdoc");
+ }
+
+ private static File getBinExecutable(String command) {
+ IVMInstall vm = RubyRuntime.getDefaultVMInstall();
+ if (vm == null) return null;
+ File installLocation = vm.getInstallLocation();
+ String path = installLocation.getAbsolutePath() + File.separator + "bin" + File.separator + command;
+ if (Platform.getOS().equals(Platform.OS_WIN32)) {
+ path += ".bat";
+ }
+ return new File(path);
+ }
}
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-30 14:08:49
|
Revision: 2396
http://svn.sourceforge.net/rubyeclipse/?rev=2396&view=rev
Author: cawilliams
Date: 2007-04-30 07:08:47 -0700 (Mon, 30 Apr 2007)
Log Message:
-----------
detect RI and Rdoc locations from our default VM install location. Now we don't need to force user to input this information, and we can detect whether we nee dto point at the .bat file by checking which platform we're on.
Modified Paths:
--------------
trunk/org.rubypeople.rdt.ui/plugin.properties
trunk/org.rubypeople.rdt.ui/plugin.xml
trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/infoviews/RIView.java
trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/rdocexport/RDocUtility.java
trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/text/ruby/hover/RiDocHoverProvider.java
trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/ui/PreferenceConstants.java
Removed Paths:
-------------
trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/preferences/RdocRiPreferencePage.java
Modified: trunk/org.rubypeople.rdt.ui/plugin.properties
===================================================================
--- trunk/org.rubypeople.rdt.ui/plugin.properties 2007-04-30 12:41:26 UTC (rev 2395)
+++ trunk/org.rubypeople.rdt.ui/plugin.properties 2007-04-30 14:08:47 UTC (rev 2396)
@@ -28,7 +28,6 @@
PreferencePage.RubyLibrary.name=Library
PreferencePage.rdtTemplatePreferences=Templates
PreferencePage.rdtTaskPreferences=Task Tags
-PreferencePage.rdtRiPreferences=Ri/rdoc
PreferencePage.rdtDebuggerPreferences=Debugger
viewCategoryName=Ruby
Modified: trunk/org.rubypeople.rdt.ui/plugin.xml
===================================================================
--- trunk/org.rubypeople.rdt.ui/plugin.xml 2007-04-30 12:41:26 UTC (rev 2395)
+++ trunk/org.rubypeople.rdt.ui/plugin.xml 2007-04-30 14:08:47 UTC (rev 2396)
@@ -47,14 +47,8 @@
category="org.rubypeople.rdt.ui.preferences.PreferencePageRubyEditor"
class="org.rubypeople.rdt.internal.ui.preferences.RubyTemplatePreferencePage"
id="org.rubypeople.rdt.ui.TemplatesPreferencePage">
- </page>
+ </page>
<page
- name="%PreferencePage.rdtRiPreferences"
- category="org.rubypeople.rdt.ui.preferences.PreferencePageRubyBase"
- class="org.rubypeople.rdt.internal.ui.preferences.RdocRiPreferencePage"
- id="org.rubypeople.rdt.ui.RdocRiPreferencePage">
- </page>
- <page
name="%memberSortPrefName"
category="org.rubypeople.rdt.ui.preferences.AppearancePreferencePage"
class="org.rubypeople.rdt.internal.ui.preferences.MembersOrderPreferencePage"
Modified: trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/infoviews/RIView.java
===================================================================
--- trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/infoviews/RIView.java 2007-04-30 12:41:26 UTC (rev 2395)
+++ trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/infoviews/RIView.java 2007-04-30 14:08:47 UTC (rev 2396)
@@ -8,16 +8,13 @@
import java.util.Collection;
import java.util.List;
-import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
-import org.eclipse.core.runtime.Path;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.IToolBarManager;
-import org.eclipse.jface.util.IPropertyChangeListener;
import org.eclipse.jface.viewers.IStructuredContentProvider;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.TableViewer;
@@ -45,9 +42,12 @@
import org.rubypeople.rdt.internal.ui.RubyPluginImages;
import org.rubypeople.rdt.internal.ui.rdocexport.RDocUtility;
import org.rubypeople.rdt.internal.ui.rdocexport.RdocListener;
-import org.rubypeople.rdt.ui.PreferenceConstants;
+import org.rubypeople.rdt.launching.IVMInstall;
+import org.rubypeople.rdt.launching.IVMInstallChangedListener;
+import org.rubypeople.rdt.launching.PropertyChangeEvent;
+import org.rubypeople.rdt.launching.RubyRuntime;
-public class RIView extends ViewPart implements RdocListener {
+public class RIView extends ViewPart implements RdocListener, IVMInstallChangedListener {
private boolean riFound = false;
private PageBook pageBook;
@@ -63,7 +63,9 @@
/**
* The constructor.
*/
- public RIView() {}
+ public RIView() {
+ RubyRuntime.addVMInstallChangedListener(this);
+ }
/**
* This is a callback that will allow us to create the viewer and initialize
@@ -129,16 +131,8 @@
// search result
searchResult = new Browser(form, SWT.BORDER);
- form.setWeights(new int[]{1, 3});
+ form.setWeights(new int[]{1, 3});
- RubyPlugin.getDefault().getPreferenceStore().addPropertyChangeListener(new IPropertyChangeListener() {
- public void propertyChange(org.eclipse.jface.util.PropertyChangeEvent event) {
- if (event.getProperty().equals(PreferenceConstants.RI_PATH)) {
- updatePage();
- }
- }
- });
-
pageBook.showPage(inProgressLabel);
updatePage();
RDocUtility.addRdocListener(this);
@@ -177,6 +171,7 @@
public void dispose() {
RDocUtility.removeRdocListener(this);
+ RubyRuntime.removeVMInstallChangedListener(this);
super.dispose();
}
@@ -244,16 +239,13 @@
protected abstract void handleOutput(Process process);
protected void beforeInvoke(){}
- public final void invoke() {
-
- IPath riPath = new Path( RubyPlugin.getDefault().getPreferenceStore().getString( PreferenceConstants.RI_PATH ) );
-
+ public final void invoke() {
// check the ri path for existence. It might have been unconfigured
// and set to the default value or the file could have been removed
- File file = new File(riPath.toOSString());
+ File file = RubyRuntime.getRI();
// If we can't find it ourselves then display an error to the user
- if (!file.exists() || !file.isFile()) {
+ if (file == null || !file.exists() || !file.isFile()) {
riFound = false;
pageBook.showPage(riNotFoundLabel);
return;
@@ -261,7 +253,7 @@
try {
List<String> args = getArgList();
- args.add(0, riPath.toString());
+ args.add(0, file.getAbsolutePath());
ProcessBuilder builder = new ProcessBuilder();
builder.command(args);
builder.redirectErrorStream(true);
@@ -389,4 +381,20 @@
riFound = false;
pageBook.showPage( riNotFoundLabel );
}
+
+ public void defaultVMInstallChanged(IVMInstall previous, IVMInstall current) {
+ updatePage();
+ }
+
+ public void vmAdded(IVMInstall newVm) {
+ // ignore
+ }
+
+ public void vmChanged(PropertyChangeEvent event) {
+ // ignore
+ }
+
+ public void vmRemoved(IVMInstall removedVm) {
+ // ignore
+ }
}
\ No newline at end of file
Deleted: trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/preferences/RdocRiPreferencePage.java
===================================================================
--- trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/preferences/RdocRiPreferencePage.java 2007-04-30 12:41:26 UTC (rev 2395)
+++ trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/preferences/RdocRiPreferencePage.java 2007-04-30 14:08:47 UTC (rev 2396)
@@ -1,53 +0,0 @@
-package org.rubypeople.rdt.internal.ui.preferences;
-
-import org.eclipse.jface.preference.FieldEditorPreferencePage;
-import org.eclipse.jface.preference.FileFieldEditor;
-import org.eclipse.ui.IWorkbench;
-import org.eclipse.ui.IWorkbenchPreferencePage;
-import org.rubypeople.rdt.internal.ui.RubyPlugin;
-import org.rubypeople.rdt.ui.PreferenceConstants;
-
-/**
- * This class represents a preference page that
- * is contributed to the Preferences dialog. By
- * subclassing <samp>FieldEditorPreferencePage</samp>, we
- * can use the field support built into JFace that allows
- * us to create a page that is small and knows how to
- * save, restore and apply itself.
- * <p>
- * This page is used to modify preferences only. They
- * are stored in the preference store that belongs to
- * the main plug-in class. That way, preferences can
- * be accessed directly via the preference store.
- */
-
-public class RdocRiPreferencePage
- extends FieldEditorPreferencePage
- implements IWorkbenchPreferencePage {
-
- public RdocRiPreferencePage() {
- super(GRID);
- setPreferenceStore(RubyPlugin.getDefault().getPreferenceStore());
- setDescription(PreferencesMessages.RiPreferencePage_description_label);
- }
-
- /**
- * Creates the field editors. Field editors are abstractions of
- * the common GUI blocks needed to manipulate various types
- * of preferences. Each field editor knows how to save and
- * restore itself.
- */
- public void createFieldEditors() {
- addField( new FileFieldEditor( PreferenceConstants.RDOC_PATH,
- PreferencesMessages.RiPreferencePage_rdocpath_label, getFieldEditorParent() ) );
-
- addField( new FileFieldEditor( PreferenceConstants.RI_PATH,
- PreferencesMessages.RiPreferencePage_ripath_label, getFieldEditorParent() ) );
- }
-
- /* (non-Javadoc)
- * @see org.eclipse.ui.IWorkbenchPreferencePage#init(org.eclipse.ui.IWorkbench)
- */
- public void init(IWorkbench workbench) {}
-
-}
\ No newline at end of file
Modified: trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/rdocexport/RDocUtility.java
===================================================================
--- trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/rdocexport/RDocUtility.java 2007-04-30 12:41:26 UTC (rev 2395)
+++ trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/rdocexport/RDocUtility.java 2007-04-30 14:08:47 UTC (rev 2396)
@@ -12,14 +12,12 @@
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
-import org.eclipse.core.runtime.IPath;
-import org.eclipse.core.runtime.Path;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.jface.dialogs.MessageDialog;
import org.rubypeople.rdt.internal.ui.RubyPlugin;
import org.rubypeople.rdt.internal.ui.RubyUIMessages;
import org.rubypeople.rdt.internal.ui.dialogs.StatusInfo;
-import org.rubypeople.rdt.ui.PreferenceConstants;
+import org.rubypeople.rdt.launching.RubyRuntime;
/**
* A utility class which will generate RDoc for a resource. If teh resource is
@@ -82,21 +80,18 @@
public final void invoke() {
log("Generating RDoc for " + resource.getName());
- IPath rdocPath = new Path(RubyPlugin.getDefault().getPreferenceStore().getString(PreferenceConstants.RDOC_PATH));
-
+ File file = RubyRuntime.getRDoc();
// check the rdoc path for existence. It might have been
// unconfigured
// and set to the default value or the file could have been removed
- File file = new File(rdocPath.toOSString());
-
// If we can't find it ourselves then display an error to the user
- if (!file.exists() || !file.isFile()) {
+ if (file == null || !file.exists() || !file.isFile()) {
MessageDialog.openError(RubyPlugin.getActiveWorkbenchShell(), RubyUIMessages.RDocPathErrorTitle, RubyUIMessages.RDocPathError);
return;
}
List<String> args = new ArrayList<String>();
- args.add(rdocPath.toString());
+ args.add(file.getAbsolutePath());
args.add("-r");
args.add(resource.getLocation().toOSString());
String[] argArray= (String[]) args.toArray(new String[args.size()]);
Modified: trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/text/ruby/hover/RiDocHoverProvider.java
===================================================================
--- trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/text/ruby/hover/RiDocHoverProvider.java 2007-04-30 12:41:26 UTC (rev 2395)
+++ trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/text/ruby/hover/RiDocHoverProvider.java 2007-04-30 14:08:47 UTC (rev 2396)
@@ -7,25 +7,23 @@
import java.util.ArrayList;
import java.util.List;
-import org.eclipse.core.runtime.IPath;
-import org.eclipse.core.runtime.Path;
import org.eclipse.jface.text.BadLocationException;
import org.eclipse.jface.text.IRegion;
import org.eclipse.jface.text.ITextViewer;
import org.eclipse.ui.IEditorInput;
import org.rubypeople.rdt.internal.ui.RubyPlugin;
-import org.rubypeople.rdt.ui.PreferenceConstants;
+import org.rubypeople.rdt.launching.IVMInstall;
+import org.rubypeople.rdt.launching.RubyRuntime;
import org.rubypeople.rdt.ui.extensions.ITextHoverProvider;
public class RiDocHoverProvider implements ITextHoverProvider {
public String getHoverInfo(IEditorInput input, ITextViewer textViewer, IRegion hoverRegion){
- IPath riPath = new Path( RubyPlugin.getDefault().getPreferenceStore().getString( PreferenceConstants.RI_PATH ) );
- File ri = riPath.toFile();
- if (!ri.exists() || !ri.isFile()) return null;
+ File ri = RubyRuntime.getRI();
+ if (ri == null || !ri.exists() || !ri.isFile()) return null;
List<String> args = new ArrayList<String>();
- args.add(0, riPath.toString());
+ args.add(0, ri.getAbsolutePath());
// these will get rid of some of the overhead formatting
args.add("-f");
args.add("simple");
Modified: trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/ui/PreferenceConstants.java
===================================================================
--- trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/ui/PreferenceConstants.java 2007-04-30 12:41:26 UTC (rev 2395)
+++ trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/ui/PreferenceConstants.java 2007-04-30 14:08:47 UTC (rev 2396)
@@ -30,14 +30,9 @@
private static String fgDefaultEncoding= System.getProperty("file.encoding"); //$NON-NLS-1$
- public static final String RI_PATH = "riDirectoryPath";
- public static final String RDOC_PATH = "rdocDirectoryPath";
public static final String DEBUGGER_USE_RUBY_DEBUG = "useRubyDebug";
public static final String TEMPLATES_USE_CODEFORMATTER = "templatesUseCodeFormatter"; //$NON-NLS-1$
-
- private final static String DEFAULT_RDOC_CMD = ""; //$NON-NLS-1$
- private final static String DEFAULT_RI_CMD = ""; //$NON-NLS-1$
private static final String LOADPATH_RUBYVMLIBRARY_INDEX= PreferenceConstants.NEWPROJECT_JRELIBRARY_INDEX;
private static final String LOADPATH_RUBYVMLIBRARY_LIST= PreferenceConstants.NEWPROJECT_JRELIBRARY_LIST;
@@ -782,9 +777,6 @@
store.setDefault(PreferenceConstants.EDITOR_SHOW_TEXT_HOVER_AFFORDANCE, true);
- store.setDefault(PreferenceConstants.RDOC_PATH, PreferenceConstants.getDefaultPath(PreferenceConstants.DEFAULT_RDOC_CMD));
- store.setDefault(PreferenceConstants.RI_PATH, PreferenceConstants.getDefaultPath(PreferenceConstants.DEFAULT_RI_CMD));
-
store.setDefault(PreferenceConstants.DEBUGGER_USE_RUBY_DEBUG, false);
store.setDefault(PreferenceConstants.EDITOR_SYNC_OUTLINE_ON_CURSOR_MOVE, true);
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-30 12:41:27
|
Revision: 2395
http://svn.sourceforge.net/rubyeclipse/?rev=2395&view=rev
Author: cawilliams
Date: 2007-04-30 05:41:26 -0700 (Mon, 30 Apr 2007)
Log Message:
-----------
when searching for declaration of a method, not only search the inferred type, but also go up the hierarchy to search included modules and superclasses
Modified Paths:
--------------
trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/codeassist/SelectionEngine.java
Modified: trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/codeassist/SelectionEngine.java
===================================================================
--- trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/codeassist/SelectionEngine.java 2007-04-30 12:27:37 UTC (rev 2394)
+++ trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/codeassist/SelectionEngine.java 2007-04-30 12:41:26 UTC (rev 2395)
@@ -2,7 +2,10 @@
import java.io.StringReader;
import java.util.ArrayList;
+import java.util.Collection;
+import java.util.HashSet;
import java.util.List;
+import java.util.Set;
import org.eclipse.core.resources.IFile;
import org.jruby.ast.ArgumentNode;
@@ -85,47 +88,95 @@
List<IRubyElement> possible = getChildrenWithName(script
.getChildren(), IRubyElement.LOCAL_VARIABLE,
getName(selected));
- return convertToArray(possible);
+ return possible.toArray(new IRubyElement[possible.size()]);
}
if (isInstanceVarRef(selected)) {
List<IRubyElement> possible = getChildrenWithName(script
.getChildren(), IRubyElement.INSTANCE_VAR,
getName(selected));
- return convertToArray(possible);
+ return possible.toArray(new IRubyElement[possible.size()]);
}
if (isClassVarRef(selected)) {
List<IRubyElement> possible = getChildrenWithName(script
.getChildren(), IRubyElement.CLASS_VAR, getName(selected));
- return convertToArray(possible);
+ return possible.toArray(new IRubyElement[possible.size()]);
}
if (isMethodCall(selected)) {
- List<IRubyElement> possible = new ArrayList<IRubyElement>();
+ Set<IRubyElement> possible = new HashSet<IRubyElement>();
ITypeInferrer inferrer = new DefaultTypeInferrer();
List<ITypeGuess> guesses = inferrer.infer(source, start);
RubyElementRequestor requestor = new RubyElementRequestor(script);
String methodName = getName(selected);
for (ITypeGuess guess : guesses) {
+
String name = guess.getType();
IType[] types = requestor.findType(name);
for (int i = 0; i < types.length; i++) {
IType type = types[i];
- IMethod[] methods = type.getMethods();
- for (int j = 0; i < methods.length; j++) {
- if (methods[j].getElementName().equals(methodName)) {
- possible.add(methods[j]);
- break;
- }
+ Collection<IMethod> methods = suggestMethods(type);
+ for (IMethod method : methods) {
+ if (method.getElementName().equals(methodName))
+ possible.add(method);
}
}
}
- return convertToArray(possible);
+ return possible.toArray(new IRubyElement[possible.size()]);
}
return new IRubyElement[0];
}
+
+ // TODO This is all copy-pasted and modified from CompletionEngine. Move this out into a util class and call it from both.
+ private Collection<IMethod> suggestMethods(IType type) throws RubyModelException {
+ List<IMethod> proposals = new ArrayList<IMethod>();
+ if (type == null) return proposals;
+ IMethod[] methods = type.getMethods();
+ for (int k = 0; k < methods.length; k++) {
+ proposals.add(methods[k]);
+ }
+ proposals.addAll(addModuleMethods(type)); // Decrement confidence by one as a hack to make sure as we move up the inheritance chain we suggest "closer" parents methods first
+ if (!type.isModule()) proposals.addAll(addSuperClassMethods(type));
+ return proposals;
+ }
- private IRubyElement findChild(String name, int type,
- IParent parent) {
+ private Collection<IMethod> addModuleMethods(IType type) {
+ List<IMethod> proposals = new ArrayList<IMethod>();
+ String[] modules = null;
try {
+ modules = type.getIncludedModuleNames();
+ } catch (RubyModelException e) {
+ // ignore
+ }
+ if (modules == null || modules.length == 0) return proposals;
+ RubyElementRequestor requestor = new RubyElementRequestor(type.getRubyScript());
+ for (int i = 0; i < modules.length; i++) {
+ IType[] moduleTypes = requestor.findType(modules[i]);
+ for (int j = 0; j < moduleTypes.length; j++) {
+ try {
+ IType moduleType = moduleTypes[j];
+ proposals.addAll(suggestMethods(moduleType));
+ } catch (RubyModelException e) {
+ // ignore
+ }
+ }
+ }
+ return proposals;
+ }
+
+ private Collection<IMethod> addSuperClassMethods(IType type) throws RubyModelException {
+ List<IMethod> proposals = new ArrayList<IMethod>();
+ String superClass = type.getSuperclassName();
+ if (superClass == null) return proposals;
+ RubyElementRequestor requestor = new RubyElementRequestor(type.getRubyScript());
+ IType[] supers = requestor.findType(superClass);
+ for (int i = 0; i < supers.length; i++) {
+ IType superType = supers[i];
+ proposals.addAll(suggestMethods(superType));
+ }
+ return proposals;
+ }
+
+ private IRubyElement findChild(String name, int type, IParent parent) {
+ try {
IRubyElement[] children = parent.getChildren();
for (int j = 0; j < children.length; j++) {
IRubyElement child = children[j];
@@ -146,15 +197,6 @@
return (selected instanceof VCallNode) || (selected instanceof FCallNode) || (selected instanceof CallNode);
}
- private IRubyElement[] convertToArray(List<IRubyElement> possible) {
- IRubyElement[] elements = new IRubyElement[possible.size()];
- int x = 0;
- for (IRubyElement element : possible) {
- elements[x++] = element;
- }
- return elements;
- }
-
private List<IRubyElement> getChildrenWithName(IRubyElement[] children,
int type, String name) throws RubyModelException {
List<IRubyElement> possible = new ArrayList<IRubyElement>();
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-30 12:27:39
|
Revision: 2394
http://svn.sourceforge.net/rubyeclipse/?rev=2394&view=rev
Author: cawilliams
Date: 2007-04-30 05:27:37 -0700 (Mon, 30 Apr 2007)
Log Message:
-----------
when we're doing method completion: in addition to trying type inferrencing, also suggest any methods that match the prefix on any type (a sort of global fallback)
Modified Paths:
--------------
trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/codeassist/CompletionEngine.java
Modified: trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/codeassist/CompletionEngine.java
===================================================================
--- trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/codeassist/CompletionEngine.java 2007-04-30 12:04:54 UTC (rev 2393)
+++ trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/codeassist/CompletionEngine.java 2007-04-30 12:27:37 UTC (rev 2394)
@@ -92,18 +92,21 @@
if (guesses.isEmpty()) {
guesses.add(new BasicTypeGuess(OBJECT, 100));
}
+ List<CompletionProposal> list = new ArrayList<CompletionProposal>();
RubyElementRequestor requestor = new RubyElementRequestor(script);
for (ITypeGuess guess : guesses) {
String name = guess.getType();
IType[] types = requestor.findType(name); // FIXME When syntax is broken, grabbing type that is defined in same script like this just doesn't work!
for (int i = 0; i < types.length; i++) {
- List<CompletionProposal> list = sort(suggestMethods(guess.getConfidence(), types[i]));
- for (CompletionProposal proposal : list) {
- fRequestor.accept(proposal);
- }
+ Map<String, CompletionProposal> map = suggestMethods(guess.getConfidence(), types[i]);
+ list.addAll(map.values());
}
}
-
+ list.addAll(suggestAllMethodsMatchingPrefix(script));
+ Collections.sort(list, new CompletionProposalComparator());
+ for (CompletionProposal proposal : list) {
+ fRequestor.accept(proposal);
+ }
} else {
// FIXME If we're invoked on the class declaration (it's super class) don't do this!
// FIXME Traverse the IRubyElement model, not nodes (and don't reparse)?
@@ -120,6 +123,32 @@
fContext = null;
}
+ private List<CompletionProposal> suggestAllMethodsMatchingPrefix(IRubyScript script) {
+ List< CompletionProposal> list = new ArrayList<CompletionProposal>();
+ IRubySearchScope scope = BasicSearchEngine.createRubySearchScope(new IRubyElement[] {script.getRubyProject()});
+ SearchParticipant participant = BasicSearchEngine.getDefaultSearchParticipant();
+ CollectingSearchRequestor searchRequestor = new CollectingSearchRequestor();
+ SearchPattern pattern = SearchPattern.createPattern(IRubyElement.METHOD, fContext.getPartialPrefix(), IRubySearchConstants.DECLARATIONS, SearchPattern.R_PREFIX_MATCH);
+ try {
+ new BasicSearchEngine().search(pattern, new SearchParticipant[] {participant}, scope, searchRequestor, null);
+ } catch (CoreException e) {
+ RubyCore.log(e);
+ }
+ List<SearchMatch> matches = searchRequestor.getResults();
+ for (SearchMatch match : matches) {
+ IMethod element = (IMethod) match.getElement();
+ IType type = element.getDeclaringType();
+ String typeName = "";
+ if (type != null)
+ typeName = type.getElementName();
+ CompletionProposal proposal = suggestMethod(element, typeName, 100); // TODO Base confidence on accuracy in match?
+ if (proposal != null) {
+ list.add(proposal);
+ }
+ }
+ return list;
+ }
+
private void suggestMethodsForEnclosingType(IRubyScript script) throws RubyModelException {
IMember element = (IMember) script.getElementAt(fContext.getOffset());
IType type = null;
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-30 12:04:55
|
Revision: 2393
http://svn.sourceforge.net/rubyeclipse/?rev=2393&view=rev
Author: cawilliams
Date: 2007-04-30 05:04:54 -0700 (Mon, 30 Apr 2007)
Log Message:
-----------
fix call to right constructor
Modified Paths:
--------------
trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/core/search/matching/MethodPattern.java
Modified: trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/core/search/matching/MethodPattern.java
===================================================================
--- trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/core/search/matching/MethodPattern.java 2007-04-30 12:04:25 UTC (rev 2392)
+++ trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/core/search/matching/MethodPattern.java 2007-04-30 12:04:54 UTC (rev 2393)
@@ -128,7 +128,7 @@
declaringQualification,
declaringSimpleName,
parameterSimpleNames,
- (IMethod)null,
+ (IType)null,
matchRule);
}
public void decodeIndexKey(char[] key) {
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-30 12:04:28
|
Revision: 2392
http://svn.sourceforge.net/rubyeclipse/?rev=2392&view=rev
Author: cawilliams
Date: 2007-04-30 05:04:25 -0700 (Mon, 30 Apr 2007)
Log Message:
-----------
when showing string representation of a string, surround with quotes
Modified Paths:
--------------
trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/core/util/ASTUtil.java
Modified: trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/core/util/ASTUtil.java
===================================================================
--- trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/core/util/ASTUtil.java 2007-04-30 12:04:08 UTC (rev 2391)
+++ trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/core/util/ASTUtil.java 2007-04-30 12:04:25 UTC (rev 2392)
@@ -117,7 +117,7 @@
if (node instanceof DStrNode)
return stringRepresentation((DStrNode) node);
if (node instanceof StrNode)
- return ((StrNode) node).getValue().toString();
+ return '"' + ((StrNode) node).getValue().toString() + '"';
log("Reached node type we don't know how to represent: "
+ node.getClass().getName());
return node.toString();
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-30 12:04:10
|
Revision: 2391
http://svn.sourceforge.net/rubyeclipse/?rev=2391&view=rev
Author: cawilliams
Date: 2007-04-30 05:04:08 -0700 (Mon, 30 Apr 2007)
Log Message:
-----------
stifle syntax errors inside type inferrer
Modified Paths:
--------------
trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/ti/DefaultTypeInferrer.java
Modified: trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/ti/DefaultTypeInferrer.java
===================================================================
--- trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/ti/DefaultTypeInferrer.java 2007-04-29 08:56:55 UTC (rev 2390)
+++ trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/internal/ti/DefaultTypeInferrer.java 2007-04-30 12:04:08 UTC (rev 2391)
@@ -22,6 +22,7 @@
import org.jruby.ast.Node;
import org.jruby.ast.RootNode;
import org.jruby.ast.VCallNode;
+import org.jruby.lexer.yacc.SyntaxException;
import org.rubypeople.rdt.internal.core.parser.RubyParser;
import org.rubypeople.rdt.internal.core.util.ASTUtil;
import org.rubypeople.rdt.internal.ti.data.LiteralNodeTypeNames;
@@ -42,14 +43,18 @@
* @return List of ITypeGuess objects.
*/
public List<ITypeGuess> infer(String source, int offset) {
- RubyParser parser = new RubyParser();
- rootNode = (RootNode) parser.parse(source);
- Node node = OffsetNodeLocator.Instance().getNodeAtOffset(rootNode.getBodyNode(), offset);
+ try {
+ RubyParser parser = new RubyParser();
+ rootNode = (RootNode) parser.parse(source);
+ Node node = OffsetNodeLocator.Instance().getNodeAtOffset(rootNode.getBodyNode(), offset);
- if (node == null) {
- return null;
+ if (node == null) {
+ return new ArrayList<ITypeGuess>();
+ }
+ return infer(node);
+ } catch (SyntaxException e) {
+ return new ArrayList<ITypeGuess>();
}
- return infer(node);
}
/**
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <mba...@us...> - 2007-04-29 08:56:59
|
Revision: 2390
http://svn.sourceforge.net/rubyeclipse/?rev=2390&view=rev
Author: mbarchfe
Date: 2007-04-29 01:56:55 -0700 (Sun, 29 Apr 2007)
Log Message:
-----------
removed entries for old download and updatsite
Modified Paths:
--------------
trunk/org.rubypeople.rdt.build/cruiseControl/config.xml
trunk/org.rubypeople.rdt.build/cruiseControl/purgeNightlyBuildWebSite.sh
Modified: trunk/org.rubypeople.rdt.build/cruiseControl/config.xml
===================================================================
--- trunk/org.rubypeople.rdt.build/cruiseControl/config.xml 2007-04-27 21:37:57 UTC (rev 2389)
+++ trunk/org.rubypeople.rdt.build/cruiseControl/config.xml 2007-04-29 08:56:55 UTC (rev 2390)
@@ -46,20 +46,6 @@
sourcedir="${buildDirectory}/results"
file="."
options="-r"
- targetuser="rubypeople"
- targethost="download.rubypeople.org"
- targetdir="~/subdomains/download/httpdocs/nightly"/>
- <scp
- sourcedir="${buildDirectory}/results/updateSite"
- file="."
- options="-r"
- targetuser="rubypeople"
- targethost="download.rubypeople.org"
- targetdir="~/subdomains/updatesite/httpdocs/nightly"/>
- <scp
- sourcedir="${buildDirectory}/results"
- file="."
- options="-r"
targetuser="mbarchfeld"
targethost="www.aptana.org"
targetdir="/var/websites/download.rubypeople.org/html/nightly"/>
Modified: trunk/org.rubypeople.rdt.build/cruiseControl/purgeNightlyBuildWebSite.sh
===================================================================
--- trunk/org.rubypeople.rdt.build/cruiseControl/purgeNightlyBuildWebSite.sh 2007-04-27 21:37:57 UTC (rev 2389)
+++ trunk/org.rubypeople.rdt.build/cruiseControl/purgeNightlyBuildWebSite.sh 2007-04-29 08:56:55 UTC (rev 2390)
@@ -1,5 +1,4 @@
#!/bin/sh
-ssh -l rubypeople download.rubypeople.org "rm -r ~/subdomains/updatesite/httpdocs/nightly; mkdir ~/subdomains/updatesite/httpdocs/nightly; rm -r ~/subdomains/download/httpdocs/nightly ; mkdir ~/subdomains/download/httpdocs/nightly"
ssh -l mbarchfeld www.aptana.org "rm -r /var/websites/updatesite.rubypeople.org/html/nightly; mkdir /var/websites/updatesite.rubypeople.org/html/nightly; rm -r /var/websites/download.rubypeople.org/html/nightly ; mkdir /var/websites/download.rubypeople.org/html/nightly"
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <mba...@us...> - 2007-04-27 21:38:01
|
Revision: 2389
http://svn.sourceforge.net/rubyeclipse/?rev=2389&view=rev
Author: mbarchfe
Date: 2007-04-27 14:37:57 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
fix not running tests due to wrong DISPLAY setting
Modified Paths:
--------------
trunk/org.rubypeople.rdt.build/cruiseControl/startCCForRDT.sh
Modified: trunk/org.rubypeople.rdt.build/cruiseControl/startCCForRDT.sh
===================================================================
--- trunk/org.rubypeople.rdt.build/cruiseControl/startCCForRDT.sh 2007-04-27 21:18:00 UTC (rev 2388)
+++ trunk/org.rubypeople.rdt.build/cruiseControl/startCCForRDT.sh 2007-04-27 21:37:57 UTC (rev 2389)
@@ -1,4 +1,4 @@
#!/bin/bash
Xvfb -nolisten tcp :1 &
-export DISPLAY=localhost:1
-~/cruisecontrol/cruisecontrol.sh -webport 8080 -jmxport 8000 $@
+export DISPLAY=:1
+~/cruisecontrol/cruisecontrol.sh -webport 8080 -jmxport 8000 $@
\ No newline at end of file
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <mba...@us...> - 2007-04-27 21:18:04
|
Revision: 2388
http://svn.sourceforge.net/rubyeclipse/?rev=2388&view=rev
Author: mbarchfe
Date: 2007-04-27 14:18:00 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
also copy nighlty build results to aptana
Modified Paths:
--------------
trunk/org.rubypeople.rdt.build/cruiseControl/config.xml
trunk/org.rubypeople.rdt.build/cruiseControl/purgeNightlyBuildWebSite.sh
Modified: trunk/org.rubypeople.rdt.build/cruiseControl/config.xml
===================================================================
--- trunk/org.rubypeople.rdt.build/cruiseControl/config.xml 2007-04-27 15:28:35 UTC (rev 2387)
+++ trunk/org.rubypeople.rdt.build/cruiseControl/config.xml 2007-04-27 21:18:00 UTC (rev 2388)
@@ -56,6 +56,20 @@
targetuser="rubypeople"
targethost="download.rubypeople.org"
targetdir="~/subdomains/updatesite/httpdocs/nightly"/>
+ <scp
+ sourcedir="${buildDirectory}/results"
+ file="."
+ options="-r"
+ targetuser="mbarchfeld"
+ targethost="www.aptana.org"
+ targetdir="/var/websites/download.rubypeople.org/html/nightly"/>
+ <scp
+ sourcedir="${buildDirectory}/results/updateSite"
+ file="."
+ options="-r"
+ targetuser="mbarchfeld"
+ targethost="www.aptana.org"
+ targetdir="/var/websites/updatesite.rubypeople.org/html/nightly"/>
</onsuccess>
<email
Modified: trunk/org.rubypeople.rdt.build/cruiseControl/purgeNightlyBuildWebSite.sh
===================================================================
--- trunk/org.rubypeople.rdt.build/cruiseControl/purgeNightlyBuildWebSite.sh 2007-04-27 15:28:35 UTC (rev 2387)
+++ trunk/org.rubypeople.rdt.build/cruiseControl/purgeNightlyBuildWebSite.sh 2007-04-27 21:18:00 UTC (rev 2388)
@@ -1,2 +1,5 @@
#!/bin/sh
ssh -l rubypeople download.rubypeople.org "rm -r ~/subdomains/updatesite/httpdocs/nightly; mkdir ~/subdomains/updatesite/httpdocs/nightly; rm -r ~/subdomains/download/httpdocs/nightly ; mkdir ~/subdomains/download/httpdocs/nightly"
+ssh -l mbarchfeld www.aptana.org "rm -r /var/websites/updatesite.rubypeople.org/html/nightly; mkdir /var/websites/updatesite.rubypeople.org/html/nightly; rm -r /var/websites/download.rubypeople.org/html/nightly ; mkdir /var/websites/download.rubypeople.org/html/nightly"
+
+
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-27 15:28:37
|
Revision: 2387
http://svn.sourceforge.net/rubyeclipse/?rev=2387&view=rev
Author: cawilliams
Date: 2007-04-27 08:28:35 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
require at least J2SE-1.5 in manifest
Modified Paths:
--------------
trunk/org.rubypeople.rdt.refactoring/META-INF/MANIFEST.MF
trunk/org.rubypeople.rdt.testunit/META-INF/MANIFEST.MF
trunk/org.rubypeople.rdt.ui/META-INF/MANIFEST.MF
Modified: trunk/org.rubypeople.rdt.refactoring/META-INF/MANIFEST.MF
===================================================================
--- trunk/org.rubypeople.rdt.refactoring/META-INF/MANIFEST.MF 2007-04-27 15:28:14 UTC (rev 2386)
+++ trunk/org.rubypeople.rdt.refactoring/META-INF/MANIFEST.MF 2007-04-27 15:28:35 UTC (rev 2387)
@@ -67,3 +67,4 @@
Eclipse-LazyStart: true
Bundle-Vendor: %rubyRefactoring.providerName
Bundle-ClassPath: refactoring.jar
+Bundle-RequiredExecutionEnvironment: J2SE-1.5
Modified: trunk/org.rubypeople.rdt.testunit/META-INF/MANIFEST.MF
===================================================================
--- trunk/org.rubypeople.rdt.testunit/META-INF/MANIFEST.MF 2007-04-27 15:28:14 UTC (rev 2386)
+++ trunk/org.rubypeople.rdt.testunit/META-INF/MANIFEST.MF 2007-04-27 15:28:35 UTC (rev 2387)
@@ -25,3 +25,4 @@
org.eclipse.compare,
org.eclipse.jface.text
Eclipse-LazyStart: true
+Bundle-RequiredExecutionEnvironment: J2SE-1.5
Modified: trunk/org.rubypeople.rdt.ui/META-INF/MANIFEST.MF
===================================================================
--- trunk/org.rubypeople.rdt.ui/META-INF/MANIFEST.MF 2007-04-27 15:28:14 UTC (rev 2386)
+++ trunk/org.rubypeople.rdt.ui/META-INF/MANIFEST.MF 2007-04-27 15:28:35 UTC (rev 2387)
@@ -60,3 +60,4 @@
org.eclipse.core.expressions,
org.eclipse.ltk.core.refactoring
Eclipse-LazyStart: true
+Bundle-RequiredExecutionEnvironment: J2SE-1.5
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-27 15:28:17
|
Revision: 2386
http://svn.sourceforge.net/rubyeclipse/?rev=2386&view=rev
Author: cawilliams
Date: 2007-04-27 08:28:14 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
add manifest, require J2SE-1.5
Modified Paths:
--------------
trunk/org.rubypeople.rdt.debug.core/build.properties
trunk/org.rubypeople.rdt.debug.core/plugin.xml
trunk/org.rubypeople.rdt.debug.ui/build.properties
trunk/org.rubypeople.rdt.debug.ui/plugin.xml
trunk/org.rubypeople.rdt.launching/build.properties
trunk/org.rubypeople.rdt.launching/plugin.xml
Added Paths:
-----------
trunk/org.rubypeople.rdt.debug.core/META-INF/
trunk/org.rubypeople.rdt.debug.core/META-INF/MANIFEST.MF
trunk/org.rubypeople.rdt.debug.ui/META-INF/
trunk/org.rubypeople.rdt.debug.ui/META-INF/MANIFEST.MF
trunk/org.rubypeople.rdt.launching/META-INF/
trunk/org.rubypeople.rdt.launching/META-INF/MANIFEST.MF
Added: trunk/org.rubypeople.rdt.debug.core/META-INF/MANIFEST.MF
===================================================================
--- trunk/org.rubypeople.rdt.debug.core/META-INF/MANIFEST.MF (rev 0)
+++ trunk/org.rubypeople.rdt.debug.core/META-INF/MANIFEST.MF 2007-04-27 15:28:14 UTC (rev 2386)
@@ -0,0 +1,20 @@
+Manifest-Version: 1.0
+Bundle-ManifestVersion: 2
+Bundle-Name: %Plugin.name
+Bundle-SymbolicName: org.rubypeople.rdt.debug.core; singleton:=true
+Bundle-Version: 0.0.0
+Bundle-ClassPath: rdtdebugcore.jar
+Bundle-Activator: org.rubypeople.rdt.internal.debug.core.RdtDebugCorePlugin
+Bundle-Vendor: %providerName
+Bundle-Localization: plugin
+Export-Package: org.rubypeople.rdt.internal.debug.core,
+ org.rubypeople.rdt.internal.debug.core.commands,
+ org.rubypeople.rdt.internal.debug.core.model,
+ org.rubypeople.rdt.internal.debug.core.parsing
+Require-Bundle: org.eclipse.core.resources,
+ org.eclipse.debug.core,
+ org.rubypeople.rdt.core,
+ org.kxml2,
+ org.eclipse.core.runtime
+Eclipse-LazyStart: true
+Bundle-RequiredExecutionEnvironment: J2SE-1.5
Modified: trunk/org.rubypeople.rdt.debug.core/build.properties
===================================================================
--- trunk/org.rubypeople.rdt.debug.core/build.properties 2007-04-27 15:27:14 UTC (rev 2385)
+++ trunk/org.rubypeople.rdt.debug.core/build.properties 2007-04-27 15:28:14 UTC (rev 2386)
@@ -1,7 +1,8 @@
bin.includes = plugin.xml,\
plugin.properties,\
.options,\
- rdtdebugcore.jar
+ rdtdebugcore.jar,\
+ META-INF/
source.rdtdebugcore.jar = src/
plugin = org.rubypeople.rdt.debug.core
plugin.name = rdtdebugcore
Modified: trunk/org.rubypeople.rdt.debug.core/plugin.xml
===================================================================
--- trunk/org.rubypeople.rdt.debug.core/plugin.xml 2007-04-27 15:27:14 UTC (rev 2385)
+++ trunk/org.rubypeople.rdt.debug.core/plugin.xml 2007-04-27 15:28:14 UTC (rev 2386)
@@ -1,27 +1,8 @@
<?xml version="1.0" encoding="UTF-8"?>
<?eclipse version="3.0"?>
-<plugin
- id="org.rubypeople.rdt.debug.core"
- name="%Plugin.name"
- version="0.0.0"
- provider-name="%providerName"
- class="org.rubypeople.rdt.internal.debug.core.RdtDebugCorePlugin">
+<plugin>
- <runtime>
- <library name="rdtdebugcore.jar">
- <export name="*"/>
- </library>
- </runtime>
-
- <requires>
- <import plugin="org.eclipse.core.resources"/>
- <import plugin="org.eclipse.debug.core"/>
- <import plugin="org.rubypeople.rdt.core"/>
- <import plugin="org.kxml2"/>
- <import plugin="org.eclipse.core.runtime"/>
- </requires>
-
- <extension
+ <extension
id="RubyBreakpointMarker"
point="org.eclipse.core.resources.markers">
<super
Added: trunk/org.rubypeople.rdt.debug.ui/META-INF/MANIFEST.MF
===================================================================
--- trunk/org.rubypeople.rdt.debug.ui/META-INF/MANIFEST.MF (rev 0)
+++ trunk/org.rubypeople.rdt.debug.ui/META-INF/MANIFEST.MF 2007-04-27 15:28:14 UTC (rev 2386)
@@ -0,0 +1,35 @@
+Manifest-Version: 1.0
+Bundle-ManifestVersion: 2
+Bundle-Name: %Plugin.name
+Bundle-SymbolicName: org.rubypeople.rdt.debug.ui; singleton:=true
+Bundle-Version: 0.0.0
+Bundle-ClassPath: rdtdebugui.jar
+Bundle-Activator: org.rubypeople.rdt.internal.debug.ui.RdtDebugUiPlugin
+Bundle-Vendor: RubyPeople, Inc.
+Bundle-Localization: plugin
+Export-Package: org.rubypeople.rdt.debug.ui,
+ org.rubypeople.rdt.internal.debug.ui,
+ org.rubypeople.rdt.internal.debug.ui.actions,
+ org.rubypeople.rdt.internal.debug.ui.console,
+ org.rubypeople.rdt.internal.debug.ui.evaluation,
+ org.rubypeople.rdt.internal.debug.ui.launcher,
+ org.rubypeople.rdt.internal.debug.ui.preferences,
+ org.rubypeople.rdt.internal.debug.ui.rubyvms
+Require-Bundle: org.eclipse.core.resources,
+ org.eclipse.ui,
+ org.eclipse.debug.core,
+ org.eclipse.debug.ui,
+ org.rubypeople.rdt.launching,
+ org.rubypeople.rdt.ui,
+ org.rubypeople.rdt.core,
+ org.rubypeople.rdt.debug.core,
+ org.eclipse.ui.workbench,
+ org.eclipse.ui.workbench.texteditor,
+ org.eclipse.jface.text,
+ org.eclipse.ui.editors,
+ org.eclipse.ui.ide,
+ org.eclipse.ui.cheatsheets,
+ org.eclipse.core.runtime,
+ org.eclipse.ui.console
+Eclipse-LazyStart: true
+Bundle-RequiredExecutionEnvironment: J2SE-1.5
Modified: trunk/org.rubypeople.rdt.debug.ui/build.properties
===================================================================
--- trunk/org.rubypeople.rdt.debug.ui/build.properties 2007-04-27 15:27:14 UTC (rev 2385)
+++ trunk/org.rubypeople.rdt.debug.ui/build.properties 2007-04-27 15:28:14 UTC (rev 2386)
@@ -5,7 +5,8 @@
rdtdebugui.jar,\
cheatsheets/,\
icons/full/,\
- expressions/rdt.xml
+ expressions/rdt.xml,\
+ META-INF/
plugin = org.rubypeople.rdt.debug.ui
plugin.name = rdtdebugui
plugin.classpath = ../org.eclipse.core.resources/resources.jar;../org.eclipse.ui/worbench.jar;../org.eclipse.core.runtime/runtime.jar;../org.eclipse.core.resources/resources.jar;../org.eclipse.core.boot/boot.jar;../org.eclipse.debug.core/dtcore.jar;../org.eclipse.debug.ui/dtui.jar;../org.eclipse.swt/bin;../org.eclipse.ui/workbench.jar;../org.eclipse.swt.${ws}/ws/${ws}/swt.jar;../org.rubypeople.rdt.core/bin;../org.rubypeople.rdt.debug.core/bin;../org.rubypeople.rdt.launching/bin;../org.rubypeople.rdt.ui/bin;
Modified: trunk/org.rubypeople.rdt.debug.ui/plugin.xml
===================================================================
--- trunk/org.rubypeople.rdt.debug.ui/plugin.xml 2007-04-27 15:27:14 UTC (rev 2385)
+++ trunk/org.rubypeople.rdt.debug.ui/plugin.xml 2007-04-27 15:28:14 UTC (rev 2386)
@@ -1,35 +1,8 @@
<?xml version="1.0" encoding="UTF-8"?>
<?eclipse version="3.0"?>
-<plugin id="org.rubypeople.rdt.debug.ui" name="%Plugin.name" version="0.0.0"
- provider-name="RubyPeople, Inc."
- class="org.rubypeople.rdt.internal.debug.ui.RdtDebugUiPlugin">
+<plugin>
- <runtime>
- <library name="rdtdebugui.jar">
- <export name="*"/>
- </library>
- </runtime>
-
- <requires>
- <import plugin="org.eclipse.core.resources"/>
- <import plugin="org.eclipse.ui"/>
- <import plugin="org.eclipse.debug.core"/>
- <import plugin="org.eclipse.debug.ui"/>
- <import plugin="org.rubypeople.rdt.launching"/>
- <import plugin="org.rubypeople.rdt.ui"/>
- <import plugin="org.rubypeople.rdt.core"/>
- <import plugin="org.rubypeople.rdt.debug.core"/>
- <import plugin="org.eclipse.ui.workbench"/>
- <import plugin="org.eclipse.ui.workbench.texteditor"/>
- <import plugin="org.eclipse.jface.text"/>
- <import plugin="org.eclipse.ui.editors"/>
- <import plugin="org.eclipse.ui.ide"/>
- <import plugin="org.eclipse.ui.cheatsheets"/>
- <import plugin="org.eclipse.core.runtime"/>
- <import plugin="org.eclipse.ui.console"/>
- </requires>
-
- <extension point="org.eclipse.ui.preferencePages">
+ <extension point="org.eclipse.ui.preferencePages">
<page name="%PreferencePage.RubyInterpreter.name"
category="org.rubypeople.rdt.ui.preferences.PreferencePageRubyBase"
class="org.rubypeople.rdt.internal.debug.ui.preferences.RubyInterpreterPreferencePage"
Added: trunk/org.rubypeople.rdt.launching/META-INF/MANIFEST.MF
===================================================================
--- trunk/org.rubypeople.rdt.launching/META-INF/MANIFEST.MF (rev 0)
+++ trunk/org.rubypeople.rdt.launching/META-INF/MANIFEST.MF 2007-04-27 15:28:14 UTC (rev 2386)
@@ -0,0 +1,19 @@
+Manifest-Version: 1.0
+Bundle-ManifestVersion: 2
+Bundle-Name: %Plugin.name
+Bundle-SymbolicName: org.rubypeople.rdt.launching; singleton:=true
+Bundle-Version: 0.0.0
+Bundle-ClassPath: launching.jar
+Bundle-Activator: org.rubypeople.rdt.internal.launching.LaunchingPlugin
+Bundle-Vendor: RubyPeople, Inc.
+Bundle-Localization: plugin
+Export-Package: org.rubypeople.rdt.internal.launching,
+ org.rubypeople.rdt.launching
+Require-Bundle: org.eclipse.core.resources,
+ org.eclipse.debug.core,
+ org.rubypeople.rdt.core,
+ org.rubypeople.rdt.debug.core,
+ org.eclipse.core.runtime,
+ org.eclipse.core.variables
+Eclipse-LazyStart: true
+Bundle-RequiredExecutionEnvironment: J2SE-1.5
Modified: trunk/org.rubypeople.rdt.launching/build.properties
===================================================================
--- trunk/org.rubypeople.rdt.launching/build.properties 2007-04-27 15:27:14 UTC (rev 2385)
+++ trunk/org.rubypeople.rdt.launching/build.properties 2007-04-27 15:28:14 UTC (rev 2386)
@@ -2,7 +2,8 @@
plugin.properties,\
ruby/*,\
launching.jar,\
- .options
+ .options,\
+ META-INF/
plugin = org.rubypeople.rdt.launching
plugin.name = launching
plugin.classpath = ../org.eclipse.core.runtime/runtime.jar;../org.eclipse.core.resources/resources.jar;../org.eclipse.core.boot/boot.jar;../org.eclipse.debug.core/dtcore.jar;../org.eclipse.ui/workbench.jar;../org.apache.xerces/xmlParserAPIs.jar;../org.rubypeople.rdt.core/bin;../org.rubypeople.rdt.debug.core/bin;
Modified: trunk/org.rubypeople.rdt.launching/plugin.xml
===================================================================
--- trunk/org.rubypeople.rdt.launching/plugin.xml 2007-04-27 15:27:14 UTC (rev 2385)
+++ trunk/org.rubypeople.rdt.launching/plugin.xml 2007-04-27 15:28:14 UTC (rev 2386)
@@ -1,28 +1,8 @@
<?xml version="1.0" encoding="UTF-8"?>
<?eclipse version="3.0"?>
-<plugin
- id="org.rubypeople.rdt.launching"
- name="%Plugin.name"
- version="0.0.0"
- provider-name="RubyPeople, Inc."
- class="org.rubypeople.rdt.internal.launching.LaunchingPlugin">
+<plugin>
- <runtime>
- <library name="launching.jar">
- <export name="*"/>
- </library>
- </runtime>
-
- <requires>
- <import plugin="org.eclipse.core.resources"/>
- <import plugin="org.eclipse.debug.core"/>
- <import plugin="org.rubypeople.rdt.core"/>
- <import plugin="org.rubypeople.rdt.debug.core"/>
- <import plugin="org.eclipse.core.runtime"/>
- <import plugin="org.eclipse.core.variables"/>
- </requires>
-
- <!-- Extension point definitions -->
+ <!-- Extension point definitions -->
<extension-point id="vmInstallTypes" name="%vmInstallTypes" schema="schema/vmInstallTypes.exsd"/>
<extension-point id="vmInstalls" name="%vmInstalls" schema="schema/vmInstalls.exsd"/>
<extension-point id="loadpathProviders" name="%loadpathProviders" schema="schema/loadpathProviders.exsd"/>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-27 15:27:16
|
Revision: 2385
http://svn.sourceforge.net/rubyeclipse/?rev=2385&view=rev
Author: cawilliams
Date: 2007-04-27 08:27:14 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
compile with 5.0
Modified Paths:
--------------
trunk/org.rubypeople.rdt.debug.ui/.settings/org.eclipse.jdt.core.prefs
trunk/org.rubypeople.rdt.debug.ui.tests/.settings/org.eclipse.jdt.core.prefs
trunk/org.rubypeople.rdt.ui/.settings/org.eclipse.jdt.core.prefs
Added Paths:
-----------
trunk/org.rubypeople.rdt.debug.core/.settings/
trunk/org.rubypeople.rdt.debug.core/.settings/org.eclipse.jdt.core.prefs
trunk/org.rubypeople.rdt.launching/.settings/
trunk/org.rubypeople.rdt.launching/.settings/org.eclipse.jdt.core.prefs
trunk/org.rubypeople.rdt.launching.tests/.settings/
trunk/org.rubypeople.rdt.launching.tests/.settings/org.eclipse.jdt.core.prefs
trunk/org.rubypeople.rdt.refactoring/.settings/
trunk/org.rubypeople.rdt.refactoring/.settings/org.eclipse.jdt.core.prefs
trunk/org.rubypeople.rdt.refactoring.tests/.settings/
trunk/org.rubypeople.rdt.refactoring.tests/.settings/org.eclipse.jdt.core.prefs
trunk/org.rubypeople.rdt.testunit/.settings/
trunk/org.rubypeople.rdt.testunit/.settings/org.eclipse.jdt.core.prefs
trunk/org.rubypeople.rdt.ui.tests/.settings/
trunk/org.rubypeople.rdt.ui.tests/.settings/org.eclipse.jdt.core.prefs
Added: trunk/org.rubypeople.rdt.debug.core/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- trunk/org.rubypeople.rdt.debug.core/.settings/org.eclipse.jdt.core.prefs (rev 0)
+++ trunk/org.rubypeople.rdt.debug.core/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:27:14 UTC (rev 2385)
@@ -0,0 +1,12 @@
+#Fri Apr 27 11:07:44 EDT 2007
+eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
+org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5
+org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve
+org.eclipse.jdt.core.compiler.compliance=1.5
+org.eclipse.jdt.core.compiler.debug.lineNumber=generate
+org.eclipse.jdt.core.compiler.debug.localVariable=generate
+org.eclipse.jdt.core.compiler.debug.sourceFile=generate
+org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
+org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
+org.eclipse.jdt.core.compiler.source=1.5
Modified: trunk/org.rubypeople.rdt.debug.ui/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- trunk/org.rubypeople.rdt.debug.ui/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:26:23 UTC (rev 2384)
+++ trunk/org.rubypeople.rdt.debug.ui/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:27:14 UTC (rev 2385)
@@ -1,12 +1,21 @@
-#Sun Oct 02 13:17:30 EDT 2005
+#Fri Apr 27 11:05:03 EDT 2007
eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
+org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5
+org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve
+org.eclipse.jdt.core.compiler.compliance=1.5
+org.eclipse.jdt.core.compiler.debug.lineNumber=generate
+org.eclipse.jdt.core.compiler.debug.localVariable=generate
+org.eclipse.jdt.core.compiler.debug.sourceFile=generate
org.eclipse.jdt.core.compiler.problem.annotationSuperInterface=warning
+org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
org.eclipse.jdt.core.compiler.problem.autoboxing=ignore
org.eclipse.jdt.core.compiler.problem.deprecation=ignore
org.eclipse.jdt.core.compiler.problem.deprecationInDeprecatedCode=disabled
org.eclipse.jdt.core.compiler.problem.deprecationWhenOverridingDeprecatedMethod=disabled
org.eclipse.jdt.core.compiler.problem.discouragedReference=ignore
org.eclipse.jdt.core.compiler.problem.emptyStatement=ignore
+org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
org.eclipse.jdt.core.compiler.problem.fieldHiding=ignore
org.eclipse.jdt.core.compiler.problem.finalParameterBound=warning
org.eclipse.jdt.core.compiler.problem.finallyBlockNotCompletingNormally=warning
@@ -45,3 +54,4 @@
org.eclipse.jdt.core.compiler.problem.unusedParameterWhenOverridingConcrete=disabled
org.eclipse.jdt.core.compiler.problem.unusedPrivateMember=warning
org.eclipse.jdt.core.compiler.problem.varargsArgumentNeedCast=warning
+org.eclipse.jdt.core.compiler.source=1.5
Modified: trunk/org.rubypeople.rdt.debug.ui.tests/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- trunk/org.rubypeople.rdt.debug.ui.tests/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:26:23 UTC (rev 2384)
+++ trunk/org.rubypeople.rdt.debug.ui.tests/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:27:14 UTC (rev 2385)
@@ -1,12 +1,21 @@
-#Sun Oct 02 13:18:11 EDT 2005
+#Fri Apr 27 11:10:36 EDT 2007
eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
+org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5
+org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve
+org.eclipse.jdt.core.compiler.compliance=1.5
+org.eclipse.jdt.core.compiler.debug.lineNumber=generate
+org.eclipse.jdt.core.compiler.debug.localVariable=generate
+org.eclipse.jdt.core.compiler.debug.sourceFile=generate
org.eclipse.jdt.core.compiler.problem.annotationSuperInterface=warning
+org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
org.eclipse.jdt.core.compiler.problem.autoboxing=ignore
org.eclipse.jdt.core.compiler.problem.deprecation=ignore
org.eclipse.jdt.core.compiler.problem.deprecationInDeprecatedCode=disabled
org.eclipse.jdt.core.compiler.problem.deprecationWhenOverridingDeprecatedMethod=disabled
org.eclipse.jdt.core.compiler.problem.discouragedReference=ignore
org.eclipse.jdt.core.compiler.problem.emptyStatement=ignore
+org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
org.eclipse.jdt.core.compiler.problem.fieldHiding=ignore
org.eclipse.jdt.core.compiler.problem.finalParameterBound=warning
org.eclipse.jdt.core.compiler.problem.finallyBlockNotCompletingNormally=warning
@@ -45,3 +54,4 @@
org.eclipse.jdt.core.compiler.problem.unusedParameterWhenOverridingConcrete=disabled
org.eclipse.jdt.core.compiler.problem.unusedPrivateMember=warning
org.eclipse.jdt.core.compiler.problem.varargsArgumentNeedCast=warning
+org.eclipse.jdt.core.compiler.source=1.5
Added: trunk/org.rubypeople.rdt.launching/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- trunk/org.rubypeople.rdt.launching/.settings/org.eclipse.jdt.core.prefs (rev 0)
+++ trunk/org.rubypeople.rdt.launching/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:27:14 UTC (rev 2385)
@@ -0,0 +1,12 @@
+#Fri Apr 27 11:05:42 EDT 2007
+eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
+org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5
+org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve
+org.eclipse.jdt.core.compiler.compliance=1.5
+org.eclipse.jdt.core.compiler.debug.lineNumber=generate
+org.eclipse.jdt.core.compiler.debug.localVariable=generate
+org.eclipse.jdt.core.compiler.debug.sourceFile=generate
+org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
+org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
+org.eclipse.jdt.core.compiler.source=1.5
Added: trunk/org.rubypeople.rdt.launching.tests/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- trunk/org.rubypeople.rdt.launching.tests/.settings/org.eclipse.jdt.core.prefs (rev 0)
+++ trunk/org.rubypeople.rdt.launching.tests/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:27:14 UTC (rev 2385)
@@ -0,0 +1,12 @@
+#Fri Apr 27 11:10:46 EDT 2007
+eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
+org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5
+org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve
+org.eclipse.jdt.core.compiler.compliance=1.5
+org.eclipse.jdt.core.compiler.debug.lineNumber=generate
+org.eclipse.jdt.core.compiler.debug.localVariable=generate
+org.eclipse.jdt.core.compiler.debug.sourceFile=generate
+org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
+org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
+org.eclipse.jdt.core.compiler.source=1.5
Added: trunk/org.rubypeople.rdt.refactoring/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- trunk/org.rubypeople.rdt.refactoring/.settings/org.eclipse.jdt.core.prefs (rev 0)
+++ trunk/org.rubypeople.rdt.refactoring/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:27:14 UTC (rev 2385)
@@ -0,0 +1,12 @@
+#Fri Apr 27 11:06:05 EDT 2007
+eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
+org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5
+org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve
+org.eclipse.jdt.core.compiler.compliance=1.5
+org.eclipse.jdt.core.compiler.debug.lineNumber=generate
+org.eclipse.jdt.core.compiler.debug.localVariable=generate
+org.eclipse.jdt.core.compiler.debug.sourceFile=generate
+org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
+org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
+org.eclipse.jdt.core.compiler.source=1.5
Added: trunk/org.rubypeople.rdt.refactoring.tests/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- trunk/org.rubypeople.rdt.refactoring.tests/.settings/org.eclipse.jdt.core.prefs (rev 0)
+++ trunk/org.rubypeople.rdt.refactoring.tests/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:27:14 UTC (rev 2385)
@@ -0,0 +1,12 @@
+#Fri Apr 27 11:10:57 EDT 2007
+eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
+org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5
+org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve
+org.eclipse.jdt.core.compiler.compliance=1.5
+org.eclipse.jdt.core.compiler.debug.lineNumber=generate
+org.eclipse.jdt.core.compiler.debug.localVariable=generate
+org.eclipse.jdt.core.compiler.debug.sourceFile=generate
+org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
+org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
+org.eclipse.jdt.core.compiler.source=1.5
Added: trunk/org.rubypeople.rdt.testunit/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- trunk/org.rubypeople.rdt.testunit/.settings/org.eclipse.jdt.core.prefs (rev 0)
+++ trunk/org.rubypeople.rdt.testunit/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:27:14 UTC (rev 2385)
@@ -0,0 +1,12 @@
+#Fri Apr 27 11:06:58 EDT 2007
+eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
+org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5
+org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve
+org.eclipse.jdt.core.compiler.compliance=1.5
+org.eclipse.jdt.core.compiler.debug.lineNumber=generate
+org.eclipse.jdt.core.compiler.debug.localVariable=generate
+org.eclipse.jdt.core.compiler.debug.sourceFile=generate
+org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
+org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
+org.eclipse.jdt.core.compiler.source=1.5
Modified: trunk/org.rubypeople.rdt.ui/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- trunk/org.rubypeople.rdt.ui/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:26:23 UTC (rev 2384)
+++ trunk/org.rubypeople.rdt.ui/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:27:14 UTC (rev 2385)
@@ -1,12 +1,21 @@
-#Sun Oct 02 13:16:45 EDT 2005
+#Fri Apr 27 11:06:34 EDT 2007
eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
+org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5
+org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve
+org.eclipse.jdt.core.compiler.compliance=1.5
+org.eclipse.jdt.core.compiler.debug.lineNumber=generate
+org.eclipse.jdt.core.compiler.debug.localVariable=generate
+org.eclipse.jdt.core.compiler.debug.sourceFile=generate
org.eclipse.jdt.core.compiler.problem.annotationSuperInterface=warning
+org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
org.eclipse.jdt.core.compiler.problem.autoboxing=ignore
org.eclipse.jdt.core.compiler.problem.deprecation=ignore
org.eclipse.jdt.core.compiler.problem.deprecationInDeprecatedCode=disabled
org.eclipse.jdt.core.compiler.problem.deprecationWhenOverridingDeprecatedMethod=disabled
org.eclipse.jdt.core.compiler.problem.discouragedReference=ignore
org.eclipse.jdt.core.compiler.problem.emptyStatement=ignore
+org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
org.eclipse.jdt.core.compiler.problem.fieldHiding=ignore
org.eclipse.jdt.core.compiler.problem.finalParameterBound=warning
org.eclipse.jdt.core.compiler.problem.finallyBlockNotCompletingNormally=warning
@@ -45,3 +54,4 @@
org.eclipse.jdt.core.compiler.problem.unusedParameterWhenOverridingConcrete=disabled
org.eclipse.jdt.core.compiler.problem.unusedPrivateMember=warning
org.eclipse.jdt.core.compiler.problem.varargsArgumentNeedCast=warning
+org.eclipse.jdt.core.compiler.source=1.5
Added: trunk/org.rubypeople.rdt.ui.tests/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- trunk/org.rubypeople.rdt.ui.tests/.settings/org.eclipse.jdt.core.prefs (rev 0)
+++ trunk/org.rubypeople.rdt.ui.tests/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:27:14 UTC (rev 2385)
@@ -0,0 +1,12 @@
+#Fri Apr 27 11:11:07 EDT 2007
+eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
+org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5
+org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve
+org.eclipse.jdt.core.compiler.compliance=1.5
+org.eclipse.jdt.core.compiler.debug.lineNumber=generate
+org.eclipse.jdt.core.compiler.debug.localVariable=generate
+org.eclipse.jdt.core.compiler.debug.sourceFile=generate
+org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
+org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
+org.eclipse.jdt.core.compiler.source=1.5
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-27 15:26:24
|
Revision: 2384
http://svn.sourceforge.net/rubyeclipse/?rev=2384&view=rev
Author: cawilliams
Date: 2007-04-27 08:26:23 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
compile with 5.0
Added Paths:
-----------
trunk/org.rubypeople.rdt.debug.core.tests/.settings/
trunk/org.rubypeople.rdt.debug.core.tests/.settings/org.eclipse.jdt.core.prefs
Added: trunk/org.rubypeople.rdt.debug.core.tests/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- trunk/org.rubypeople.rdt.debug.core.tests/.settings/org.eclipse.jdt.core.prefs (rev 0)
+++ trunk/org.rubypeople.rdt.debug.core.tests/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:26:23 UTC (rev 2384)
@@ -0,0 +1,12 @@
+#Fri Apr 27 11:10:24 EDT 2007
+eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
+org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5
+org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve
+org.eclipse.jdt.core.compiler.compliance=1.5
+org.eclipse.jdt.core.compiler.debug.lineNumber=generate
+org.eclipse.jdt.core.compiler.debug.localVariable=generate
+org.eclipse.jdt.core.compiler.debug.sourceFile=generate
+org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
+org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
+org.eclipse.jdt.core.compiler.source=1.5
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-27 15:26:10
|
Revision: 2383
http://svn.sourceforge.net/rubyeclipse/?rev=2383&view=rev
Author: cawilliams
Date: 2007-04-27 08:26:09 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
compile with 5.0
Added Paths:
-----------
trunk/org.rubypeople.rdt.core.tests/.settings/
trunk/org.rubypeople.rdt.core.tests/.settings/org.eclipse.jdt.core.prefs
Added: trunk/org.rubypeople.rdt.core.tests/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- trunk/org.rubypeople.rdt.core.tests/.settings/org.eclipse.jdt.core.prefs (rev 0)
+++ trunk/org.rubypeople.rdt.core.tests/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:26:09 UTC (rev 2383)
@@ -0,0 +1,12 @@
+#Fri Apr 27 11:09:54 EDT 2007
+eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
+org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5
+org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve
+org.eclipse.jdt.core.compiler.compliance=1.5
+org.eclipse.jdt.core.compiler.debug.lineNumber=generate
+org.eclipse.jdt.core.compiler.debug.localVariable=generate
+org.eclipse.jdt.core.compiler.debug.sourceFile=generate
+org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
+org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
+org.eclipse.jdt.core.compiler.source=1.5
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-27 15:25:50
|
Revision: 2382
http://svn.sourceforge.net/rubyeclipse/?rev=2382&view=rev
Author: cawilliams
Date: 2007-04-27 08:25:48 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
compile with 5.0, require at least J2SE-1.5 in manifest
Modified Paths:
--------------
trunk/org.rubypeople.rdt.core/META-INF/MANIFEST.MF
Added Paths:
-----------
trunk/org.rubypeople.rdt.core/.settings/
trunk/org.rubypeople.rdt.core/.settings/org.eclipse.jdt.core.prefs
Added: trunk/org.rubypeople.rdt.core/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- trunk/org.rubypeople.rdt.core/.settings/org.eclipse.jdt.core.prefs (rev 0)
+++ trunk/org.rubypeople.rdt.core/.settings/org.eclipse.jdt.core.prefs 2007-04-27 15:25:48 UTC (rev 2382)
@@ -0,0 +1,12 @@
+#Fri Apr 27 11:03:12 EDT 2007
+eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
+org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5
+org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve
+org.eclipse.jdt.core.compiler.compliance=1.5
+org.eclipse.jdt.core.compiler.debug.lineNumber=generate
+org.eclipse.jdt.core.compiler.debug.localVariable=generate
+org.eclipse.jdt.core.compiler.debug.sourceFile=generate
+org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
+org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
+org.eclipse.jdt.core.compiler.source=1.5
Modified: trunk/org.rubypeople.rdt.core/META-INF/MANIFEST.MF
===================================================================
--- trunk/org.rubypeople.rdt.core/META-INF/MANIFEST.MF 2007-04-27 15:25:00 UTC (rev 2381)
+++ trunk/org.rubypeople.rdt.core/META-INF/MANIFEST.MF 2007-04-27 15:25:48 UTC (rev 2382)
@@ -32,3 +32,4 @@
org.jruby,
org.eclipse.core.filesystem
Eclipse-LazyStart: true
+Bundle-RequiredExecutionEnvironment: J2SE-1.5
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-27 15:25:01
|
Revision: 2381
http://svn.sourceforge.net/rubyeclipse/?rev=2381&view=rev
Author: cawilliams
Date: 2007-04-27 08:25:00 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
clean up messages
Modified Paths:
--------------
trunk/org.rubypeople.rdt.debug.ui/src/org/rubypeople/rdt/internal/debug/ui/RdtDebugUiMessages.properties
Modified: trunk/org.rubypeople.rdt.debug.ui/src/org/rubypeople/rdt/internal/debug/ui/RdtDebugUiMessages.properties
===================================================================
--- trunk/org.rubypeople.rdt.debug.ui/src/org/rubypeople/rdt/internal/debug/ui/RdtDebugUiMessages.properties 2007-04-27 14:18:33 UTC (rev 2380)
+++ trunk/org.rubypeople.rdt.debug.ui/src/org/rubypeople/rdt/internal/debug/ui/RdtDebugUiMessages.properties 2007-04-27 15:25:00 UTC (rev 2381)
@@ -11,15 +11,6 @@
#########################################
-# RubyApplicationWizardPage
-#########################################
-
-RubyApplicationWizardPage_name=Ruby Application Wizard
-RubyApplicationWizardPage_description=Configure and Launch a Ruby application
-RubyApplicationWizardPage_title=Ruby Application Launch Wizard
-
-
-#########################################
# LaunchConfigurationTab
#########################################
@@ -53,13 +44,6 @@
# Ruby Interpreter configuration
#########################################
-EditInterpreterDialog_rubyInterpreter_path_label=Location:
-EditInterpreterDialog_rubyInterpreter_path_browse_button_label=Browse...
-EditInterpreterDialog_rubyInterpreter_path_error=Please select a ruby interpreter
-EditInterpreterDialog_rubyInterpreter_name=Interpreter Name:
-EditInterpreterDialog_rubyInterpreter_name_error=Name cannot be empty
-EditInterpreterDialog_rubyInterpreter_path_browse_message=Choose location
-
RubyInterpreterPreferencePage_addButton_label=Add
RubyInterpreterPreferencePage_editButton_label=Edit
RubyInterpreterPreferencePage_removeButton_label=Remove
@@ -67,9 +51,6 @@
RubyInterpreterPreferencePage_rubyInterpreterTable_interpreterPath=Location
RubyInterpreterPreferencePage_rubyInterpreterTable_interpreterType=Type
-RubyInterpreterPreferencePage_EditInterpreterDialog_addInterpreter_title=Add Interpreter
-RubyInterpreterPreferencePage_EditInterpreterDialog_editInterpreter_title=Edit Interpreter
-
#########################################
# Information Dialog
#########################################
@@ -110,7 +91,6 @@
EvaluationExpressionsPreferencePage_export_error_title= Exporting Expressions
EvaluationExpressionsPreferencePage_export_error_hidden= Export failed.\n{0} is a hidden file.
EvaluationExpressionsPreferencePage_export_error_canNotWrite= Export failed.\n{0} cannot be modified.
-EvaluationExpressionsPreferencePage_export_error_fileNotFound= Export failed:\n{0}
ModifyCatchpointDialog_title=Define Catchpoint
ModifyCatchpointDialog_message=Enter the name of a ruby exception. The debugger halts when an exception of this type or a subclass is raised.
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-27 14:18:35
|
Revision: 2380
http://svn.sourceforge.net/rubyeclipse/?rev=2380&view=rev
Author: cawilliams
Date: 2007-04-27 07:18:33 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
really set VM install location to parent directory if user selects bin dir.
Modified Paths:
--------------
trunk/org.rubypeople.rdt.debug.ui/src/org/rubypeople/rdt/internal/debug/ui/rubyvms/AddVMDialog.java
Modified: trunk/org.rubypeople.rdt.debug.ui/src/org/rubypeople/rdt/internal/debug/ui/rubyvms/AddVMDialog.java
===================================================================
--- trunk/org.rubypeople.rdt.debug.ui/src/org/rubypeople/rdt/internal/debug/ui/rubyvms/AddVMDialog.java 2007-04-27 13:41:36 UTC (rev 2379)
+++ trunk/org.rubypeople.rdt.debug.ui/src/org/rubypeople/rdt/internal/debug/ui/rubyvms/AddVMDialog.java 2007-04-27 14:18:33 UTC (rev 2380)
@@ -375,6 +375,9 @@
protected void setFieldValuesToVM(IVMInstall vm) {
File dir = new File(fRubyVMRoot.getText());
+ if (dir.getName().equals("bin")) {
+ dir = dir.getParentFile();
+ }
try {
vm.setInstallLocation(dir.getCanonicalFile());
} catch (IOException e) {
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-27 13:41:37
|
Revision: 2379
http://svn.sourceforge.net/rubyeclipse/?rev=2379&view=rev
Author: cawilliams
Date: 2007-04-27 06:41:36 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
handle both migrating legacy users and persisted vms in new format.
Modified Paths:
--------------
trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/VMDefinitionsContainer.java
Modified: trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/VMDefinitionsContainer.java
===================================================================
--- trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/preferences/PreferencesMessages.java 2007-04-27 13:17:25 UTC (rev 2377)
+++ trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/preferences/PreferencesMessages.java 2007-04-27 13:33:04 UTC (rev 2378)
@@ -132,30 +132,8 @@
public static String ProblemSeveritiesConfigurationBlock_warning;
public static String ProblemSeveritiesConfigurationBlock_ignore;
public static String ProblemSeveritiesConfigurationBlock_common_description;
- public static String ProblemSeveritiesConfigurationBlock_section_unnecessary_code;
- public static String ProblemSeveritiesConfigurationBlock_section_potential_programming_problems;
- public static String ProblemSeveritiesConfigurationBlock_pb_ensure_block_not_completing_label;
public static String ProblemSeveritiesConfigurationBlock_pb_empty_statement_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_hidden_rescueblock_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_fall_through_case;
- public static String ProblemSeveritiesConfigurationBlock_pb_null_reference;
- public static String ProblemSeveritiesConfigurationBlock_pb_unused_local_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_unused_parameter_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_unused_private_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_unnecessary_else_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_misspelled_constructor_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_possible_accidental_boolean_assignment_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_local_masks_method_label;
- public static String ProblemSeveritiesConfigurationBlock_section_code_complexity;
- public static String ProblemSeveritiesConfigurationBlock_pb_max_lines_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_max_locals_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_max_arguments_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_max_branches_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_max_returns_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_similar_variable_names_label;
public static String ProblemSeveritiesConfigurationBlock_pb_unreachable_code_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_comparable_missing_method_label;
- public static String ProblemSeveritiesConfigurationBlock_pb_enumerable_missing_method_label;
public static String RubyEditorPreferencePage_background_color;
public static String MarkOccurrencesConfigurationBlock_markOccurrences;
@@ -176,14 +154,11 @@
public static String ProjectSelectionDialog_filter;
public static String FoldingConfigurationBlock_enable;
public static String FoldingConfigurationBlock_combo_caption;
- public static String NewJavaProjectPreferencePage_error_decode;
- public static String NewJavaProjectPreferencePage_jre_variable_description;
- public static String NewJavaProjectPreferencePage_jre_container_description;
public static String RubyBuildConfigurationBlock_empty_input;
public static String RubyBuildConfigurationBlock_invalid_input;
- public static String BuildPathsPropertyPage_unsavedchanges_title;
+ public static String BuildPathsPropertyPage_unsavedchanges_title;
public static String BuildPathsPropertyPage_unsavedchanges_message;
public static String BuildPathsPropertyPage_unsavedchanges_button_save;
public static String BuildPathsPropertyPage_unsavedchanges_button_discard;
Modified: trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/preferences/PreferencesMessages.properties
===================================================================
--- trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/preferences/PreferencesMessages.properties 2007-04-27 13:17:25 UTC (rev 2377)
+++ trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/preferences/PreferencesMessages.properties 2007-04-27 13:33:04 UTC (rev 2378)
@@ -146,12 +146,7 @@
ProblemSeveritiesConfigurationBlock_common_description=Select the severity level for the following Ruby compiler problems:
-ProblemSeveritiesConfigurationBlock_pb_ensure_block_not_completing_label='&ensure' does not complete normally:
ProblemSeveritiesConfigurationBlock_pb_empty_statement_label=Empty statement:
-ProblemSeveritiesConfigurationBlock_pb_hidden_rescueblock_label=Hidden rescue bloc&k:
-ProblemSeveritiesConfigurationBlock_pb_fall_through_case='case' fall-through:
-ProblemSeveritiesConfigurationBlock_pb_null_reference=Null reference:
-ProblemSeveritiesConfigurationBlock_pb_unused_local_label=&Local variable is never read:
ProblemSeveritiesConfigurationBlock_pb_unreachable_code_label=Unreachable code:
MarkOccurrencesConfigurationBlock_title= &Mark Occurrences
@@ -181,4 +176,35 @@
FoldingConfigurationBlock_combo_caption= Select folding to &use:
RubyBuildConfigurationBlock_empty_input=Number cannot be empty.
-NewJavaProjectPreferencePage_jre_container_description=RubyVM container
\ No newline at end of file
+
+NewRubyProjectPreferencePage_title=New Project
+NewRubyProjectPreferencePage_description=Specify the build path entries used as default by the New Ruby Project creation wizard:
+
+NewRubyProjectPreferencePage_sourcefolder_label=Source and output folder
+NewRubyProjectPreferencePage_sourcefolder_project=&Project
+NewRubyProjectPreferencePage_sourcefolder_folder=&Folders
+NewRubyProjectPreferencePage_folders_src=&Source folder name:
+
+NewRubyProjectPreferencePage_jrelibrary_label=As &Ruby VM library use:
+NewRubyProjectPreferencePage_jre_variable_description=JRE_LIB variable
+NewRubyProjectPreferencePage_jre_container_description=RubyVM container
+
+NewRubyProjectPreferencePage_folders_error_namesempty=Enter folder names.
+NewRubyProjectPreferencePage_folders_error_invalidsrcname=Invalid source folder name: {0}
+NewRubyProjectPreferencePage_folders_error_invalidcp=Settings will result in an invalid build path. Check for nested folders.
+
+NewRubyProjectPreferencePage_error_decode=Error while decoding Ruby VM entry
+
+BuildPathsPropertyPage_error_message=An error occurred while setting the build path
+BuildPathsPropertyPage_error_title=Error Setting Build Path
+BuildPathsPropertyPage_job_title=Setting build path
+BuildPathsPropertyPage_no_java_project_message=Not a Ruby project.
+BuildPathsPropertyPage_closed_project_message=Java information is not available for a closed project.
+
+BuildPathsPropertyPage_unsavedchanges_title=Setting Ruby Build Path
+BuildPathsPropertyPage_unsavedchanges_message=The Ruby Build path property page contains unsaved modifications. Do you want to save changes so that other build path related property pages can be updated?
+BuildPathsPropertyPage_unsavedchanges_button_save=Apply
+BuildPathsPropertyPage_unsavedchanges_button_discard=Discard
+BuildPathsPropertyPage_unsavedchanges_button_ignore=Apply Later
+
+RubyBuildConfigurationBlock_invalid_input={0} is not a valid number of problems.
\ No newline at end of file
Modified: trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/ui/PreferenceConstants.java
===================================================================
--- trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/ui/PreferenceConstants.java 2007-04-27 13:17:25 UTC (rev 2377)
+++ trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/ui/PreferenceConstants.java 2007-04-27 13:33:04 UTC (rev 2378)
@@ -693,10 +693,10 @@
private static String getDefaultRubyVMLibraries() {
StringBuffer buf= new StringBuffer();
ILoadpathEntry cntentry= getRubyVMContainerEntry();
- buf.append(encodeRubyVMLibrary(PreferencesMessages.NewJavaProjectPreferencePage_jre_container_description, new ILoadpathEntry[] { cntentry} ));
+ buf.append(encodeRubyVMLibrary(PreferencesMessages.NewRubyProjectPreferencePage_jre_container_description, new ILoadpathEntry[] { cntentry} ));
buf.append(';');
ILoadpathEntry varentry= getRubyVMVariableEntry();
- buf.append(encodeRubyVMLibrary(PreferencesMessages.NewJavaProjectPreferencePage_jre_variable_description, new ILoadpathEntry[] { varentry }));
+ buf.append(encodeRubyVMLibrary(PreferencesMessages.NewRubyProjectPreferencePage_jre_variable_description, new ILoadpathEntry[] { varentry }));
buf.append(';');
return buf.toString();
}
@@ -894,10 +894,10 @@
break;
}
} catch (NumberFormatException e) {
- String message= PreferencesMessages.NewJavaProjectPreferencePage_error_decode;
+ String message= PreferencesMessages.NewRubyProjectPreferencePage_error_decode;
RubyPlugin.log(new Status(IStatus.ERROR, RubyUI.ID_PLUGIN, IStatus.ERROR, message, e));
} catch (NoSuchElementException e) {
- String message= PreferencesMessages.NewJavaProjectPreferencePage_error_decode;
+ String message= PreferencesMessages.NewRubyProjectPreferencePage_error_decode;
RubyPlugin.log(new Status(IStatus.ERROR, RubyUI.ID_PLUGIN, IStatus.ERROR, message, e));
}
}
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-27 13:17:26
|
Revision: 2377
http://svn.sourceforge.net/rubyeclipse/?rev=2377&view=rev
Author: cawilliams
Date: 2007-04-27 06:17:25 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
create the menu path that ModifyCatchpoint refers to
Modified Paths:
--------------
trunk/org.rubypeople.rdt.debug.ui/plugin.xml
Modified: trunk/org.rubypeople.rdt.debug.ui/plugin.xml
===================================================================
--- trunk/org.rubypeople.rdt.debug.ui/plugin.xml 2007-04-27 13:17:07 UTC (rev 2376)
+++ trunk/org.rubypeople.rdt.debug.ui/plugin.xml 2007-04-27 13:17:25 UTC (rev 2377)
@@ -290,6 +290,12 @@
id="org.rubypeople.rdt.debug.ui.RDTDebugActionSet"
label="Ruby Debug"
visible="true">
+ <menu
+ id="org.eclipse.ui.run"
+ label="Run"
+ path="additions">
+ <separator name="breakpointGroup"/>
+ </menu>
<action
definitionId="org.rubypeople.rdt.debug.ui.commands.ModifyCatchpoint"
label="%modifyCatchpoint.label"
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-27 13:17:09
|
Revision: 2376
http://svn.sourceforge.net/rubyeclipse/?rev=2376&view=rev
Author: cawilliams
Date: 2007-04-27 06:17:07 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
add some missing messages
Modified Paths:
--------------
trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/actions/ActionMessages.properties
Modified: trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/actions/ActionMessages.properties
===================================================================
--- trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/actions/ActionMessages.properties 2007-04-27 12:34:10 UTC (rev 2375)
+++ trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/actions/ActionMessages.properties 2007-04-27 13:17:07 UTC (rev 2376)
@@ -11,6 +11,7 @@
###############################################################################
OpenWithMenu_label=Open Wit&h
+BuildPath_label=&Build Path
OpenAction_label=&Open
OpenAction_tooltip=Open an Editor on the Selected Element
@@ -50,3 +51,12 @@
ActionUtil_notOnBuildPath_title=Cannot Perform Operation
ActionUtil_notOnBuildPath_message=The resource is not on the build path of a Ruby project.
+
+OpenNewSourceFolderWizardAction_description=Opens the new Ruby source folder wizard
+OpenNewSourceFolderWizardAction_tooltip=Opens the new Ruby source folder wizard
+OpenNewSourceFolderWizardAction_text2=New Source Folder...
+
+OpenNewRubyProjectWizardAction_text=Ruby Project
+OpenNewRubyProjectWizardAction_description=Opens the new Ruby project wizard
+OpenNewRubyProjectWizardAction_tooltip=Opens the new Ruby project wizard
+
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-27 12:34:11
|
Revision: 2375
http://svn.sourceforge.net/rubyeclipse/?rev=2375&view=rev
Author: cawilliams
Date: 2007-04-27 05:34:10 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
fix grammar typo.
Modified Paths:
--------------
trunk/org.rubypeople.rdt.debug.ui/src/org/rubypeople/rdt/internal/debug/ui/rubyvms/RubyVMMessages.properties
Modified: trunk/org.rubypeople.rdt.debug.ui/src/org/rubypeople/rdt/internal/debug/ui/rubyvms/RubyVMMessages.properties
===================================================================
--- trunk/org.rubypeople.rdt.debug.ui/src/org/rubypeople/rdt/internal/debug/ui/rubyvms/RubyVMMessages.properties 2007-04-26 15:28:42 UTC (rev 2374)
+++ trunk/org.rubypeople.rdt.debug.ui/src/org/rubypeople/rdt/internal/debug/ui/rubyvms/RubyVMMessages.properties 2007-04-27 12:34:10 UTC (rev 2375)
@@ -1,4 +1,4 @@
-enterRubyInstallLocation=Please enter or browse to your the ruby install location.\nThis will typically be /usr, /usr/local, /opt or C:\\ruby.\nThis is the location of the ruby install, not the executable.\nWe will auto-detect the executable from this path.
+enterRubyInstallLocation=Please enter or browse to the ruby install location.\nThis will typically be /usr, /usr/local, /opt or C:\\ruby.\nThis is the location of the ruby install, not the executable.\nWe will auto-detect the executable from this path.
addVMDialog_pickJRERootDialog_message=Select the root directory of the Ruby installation:\n(For *nix systems, this may be /usr or /usr/local. If the ruby executable is in /usr/local/bin/ruby, use /usr/local).
addVMDialog_enterLocation=Enter the location of the Ruby VM.
addVMDialog_locationNotExists=The location does not exist.
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-26 15:28:45
|
Revision: 2374
http://svn.sourceforge.net/rubyeclipse/?rev=2374&view=rev
Author: cawilliams
Date: 2007-04-26 08:28:42 -0700 (Thu, 26 Apr 2007)
Log Message:
-----------
toggle the lastWasComment boolean in nextToken, not in getTokenLength or getTokenOffset since we can't guarantee the order those are called (but it is a little safer to assume that we can toggel it on next call to nextToken() ).
Modified Paths:
--------------
trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/text/ruby/RubyTokenScanner.java
Modified: trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/text/ruby/RubyTokenScanner.java
===================================================================
--- trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/text/ruby/RubyTokenScanner.java 2007-04-26 13:11:18 UTC (rev 2373)
+++ trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/text/ruby/RubyTokenScanner.java 2007-04-26 15:28:42 UTC (rev 2374)
@@ -76,7 +76,6 @@
public int getTokenLength() {
if (lastWasComment) {
- lastWasComment = false;
return tokenLength;
}
if (fSavedLength != -1) {
@@ -100,6 +99,9 @@
}
public IToken nextToken() {
+ if (lastWasComment) {
+ lastWasComment = false;
+ }
if (fSavedToken != null) {
IToken returnToken = fSavedToken;
fSavedToken = null;
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-26 13:11:19
|
Revision: 2373
http://svn.sourceforge.net/rubyeclipse/?rev=2373&view=rev
Author: cawilliams
Date: 2007-04-26 06:11:18 -0700 (Thu, 26 Apr 2007)
Log Message:
-----------
grab root of ruby install from executable, not path to bin folder...
Modified Paths:
--------------
trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/VMDefinitionsContainer.java
Modified: trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/VMDefinitionsContainer.java
===================================================================
--- trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/VMDefinitionsContainer.java 2007-04-26 11:23:58 UTC (rev 2372)
+++ trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/VMDefinitionsContainer.java 2007-04-26 13:11:18 UTC (rev 2373)
@@ -28,7 +28,6 @@
import javax.xml.transform.TransformerException;
import org.eclipse.core.runtime.IPath;
-import org.eclipse.core.runtime.Path;
import org.rubypeople.rdt.launching.IVMInstall;
import org.rubypeople.rdt.launching.IVMInstall2;
import org.rubypeople.rdt.launching.IVMInstallType;
@@ -405,7 +404,10 @@
File installLocation= new File(installPath);
// If the path is to the executable (which it should be), chop off last part of path!
if (installLocation.isFile()) {
- installLocation = installLocation.getParentFile();
+ installLocation = installLocation.getParentFile(); // move up to "bin"
+ if (installLocation != null && installLocation.getParentFile() != null) {
+ installLocation = installLocation.getParentFile(); // this should now be ruby install location
+ }
}
vmStandin.setInstallLocation(installLocation);
container.addVM(vmStandin);
@@ -415,36 +417,6 @@
}
/**
- * Create & return a LibraryLocation object populated from the attribute values
- * in the specified node.
- */
- private static IPath getLibraryLocation(Element libLocationElement) {
- String src= libLocationElement.getAttribute("src"); //$NON-NLS-1$
- return new Path(src);
- }
-
- /**
- * Set the LibraryLocations on the specified VM, by extracting the subordinate
- * nodes from the specified 'lirbaryLocations' node.
- */
- private static void setLibraryLocations(IVMInstall vm, Element libLocationsElement) {
- NodeList list = libLocationsElement.getChildNodes();
- int length = list.getLength();
- List<IPath> locations = new ArrayList<IPath>(length);
- for (int i = 0; i < length; ++i) {
- Node node = list.item(i);
- short type = node.getNodeType();
- if (type == Node.ELEMENT_NODE) {
- Element libraryLocationElement= (Element)node;
- if (libraryLocationElement.getNodeName().equals("libraryLocation")) { //$NON-NLS-1$
- locations.add(getLibraryLocation(libraryLocationElement));
- }
- }
- }
- vm.setLibraryLocations(locations.toArray(new IPath[locations.size()]));
- }
-
- /**
* Removes the VM from this container.
*
* @param vm vm intall
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
--- trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/VMDefinitionsContainer.java 2007-04-27 13:33:04 UTC (rev 2378)
+++ trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/VMDefinitionsContainer.java 2007-04-27 13:41:36 UTC (rev 2379)
@@ -28,6 +28,7 @@
import javax.xml.transform.TransformerException;
import org.eclipse.core.runtime.IPath;
+import org.eclipse.core.runtime.Path;
import org.rubypeople.rdt.launching.IVMInstall;
import org.rubypeople.rdt.launching.IVMInstall2;
import org.rubypeople.rdt.launching.IVMInstallType;
@@ -362,13 +363,146 @@
stream.close();
}
- // If the top-level node wasn't what we expected, bail out
- if (!config.getNodeName().equalsIgnoreCase("runtimeconfig")) { //$NON-NLS-1$
+ String nodeName = config.getNodeName();
+ if (nodeName.equalsIgnoreCase("runtimeconfig")) {
+ // Do the legacy stuff
+ importLegacyInterpreters(config, container);
+ return;
+ } else if (!config.getNodeName().equalsIgnoreCase("vmSettings")) { //$NON-NLS-1$
+ // If the top-level node wasn't what we expected, bail out
throw new IOException(LaunchingMessages.RubyRuntime_badFormat);
}
+ // Populate the default VM-related fields
+ container.setDefaultVMInstallCompositeID(config.getAttribute("defaultVM")); //$NON-NLS-1$
+
+ // Traverse the parsed structure and populate the VMType to VM Map
+ NodeList list = config.getChildNodes();
+ int length = list.getLength();
+ for (int i = 0; i < length; ++i) {
+ Node node = list.item(i);
+ short type = node.getNodeType();
+ if (type == Node.ELEMENT_NODE) {
+ Element vmTypeElement = (Element) node;
+ if (vmTypeElement.getNodeName().equalsIgnoreCase("vmType")) { //$NON-NLS-1$
+ populateVMTypes(vmTypeElement, container);
+ }
+ }
+ }
+ }
+
+ /**
+ * For the specified vm type node, parse all subordinate VM definitions and add them
+ * to the specified container.
+ */
+ private static void populateVMTypes(Element vmTypeElement, VMDefinitionsContainer container) {
+
+ // Retrieve the 'id' attribute and the corresponding VM type object
+ String id = vmTypeElement.getAttribute("id"); //$NON-NLS-1$
+ IVMInstallType vmType= RubyRuntime.getVMInstallType(id);
+ if (vmType != null) {
+
+ // For each VM child node, populate the container with a subordinate node
+ NodeList vmNodeList = vmTypeElement.getChildNodes();
+ for (int i = 0; i < vmNodeList.getLength(); ++i) {
+ Node vmNode = vmNodeList.item(i);
+ short type = vmNode.getNodeType();
+ if (type == Node.ELEMENT_NODE) {
+ Element vmElement = (Element) vmNode;
+ if (vmElement.getNodeName().equalsIgnoreCase("vm")) { //$NON-NLS-1$
+ populateVMForType(vmType, vmElement, container);
+ }
+ }
+ }
+ } else {
+ LaunchingPlugin.log(LaunchingMessages.RubyRuntime_VM_type_element_with_unknown_id_1);
+ }
+ }
+
+ /**
+ * Parse the specified VM node, create a VMStandin for it, and add this to the
+ * specified container.
+ */
+ private static void populateVMForType(IVMInstallType vmType, Element vmElement, VMDefinitionsContainer container) {
+ String id= vmElement.getAttribute("id"); //$NON-NLS-1$
+ if (id != null) {
+
+ // Retrieve the 'path' attribute. If none, skip this node.
+ String installPath= vmElement.getAttribute("path"); //$NON-NLS-1$
+ if (installPath == null) {
+ return;
+ }
+
+ // Create a VMStandin for the node and set its 'name' & 'installLocation' attributes
+ VMStandin vmStandin = new VMStandin(vmType, id);
+ vmStandin.setName(vmElement.getAttribute("name")); //$NON-NLS-1$
+ File installLocation= new File(installPath);
+ vmStandin.setInstallLocation(installLocation);
+ container.addVM(vmStandin);
+
+ // Look for subordinate nodes. These may be 'libraryLocation',
+ // 'libraryLocations' or 'versionInfo'.
+ NodeList list = vmElement.getChildNodes();
+ int length = list.getLength();
+ for (int i = 0; i < length; ++i) {
+ Node node = list.item(i);
+ short type = node.getNodeType();
+ if (type == Node.ELEMENT_NODE) {
+ Element subElement = (Element)node;
+ String subElementName = subElement.getNodeName();
+ if (subElementName.equals("libraryLocation")) { //$NON-NLS-1$
+ IPath loc = getLibraryLocation(subElement);
+ vmStandin.setLibraryLocations(new IPath[]{loc});
+ break;
+ } else if (subElementName.equals("libraryLocations")) { //$NON-NLS-1$
+ setLibraryLocations(vmStandin, subElement);
+ break;
+ }
+ }
+ }
+
+ // vm Arguments
+ String vmArgs = vmElement.getAttribute("vmargs"); //$NON-NLS-1$
+ if (vmArgs != null && vmArgs.length() >0) {
+ vmStandin.setVMArgs(vmArgs);
+ }
+ } else {
+ LaunchingPlugin.log(LaunchingMessages.RubyRuntime_VM_element_specified_with_no_id_attribute_2);
+ }
+ }
+
+ /**
+ * Create & return a LibraryLocation object populated from the attribute values
+ * in the specified node.
+ */
+ private static IPath getLibraryLocation(Element libLocationElement) {
+ String src= libLocationElement.getAttribute("src"); //$NON-NLS-1$
+ return new Path(src);
+ }
+
+ /**
+ * Set the LibraryLocations on the specified VM, by extracting the subordinate
+ * nodes from the specified 'lirbaryLocations' node.
+ */
+ private static void setLibraryLocations(IVMInstall vm, Element libLocationsElement) {
+ NodeList list = libLocationsElement.getChildNodes();
+ int length = list.getLength();
+ List<IPath> locations = new ArrayList<IPath>(length);
+ for (int i = 0; i < length; ++i) {
+ Node node = list.item(i);
+ short type = node.getNodeType();
+ if (type == Node.ELEMENT_NODE) {
+ Element libraryLocationElement= (Element)node;
+ if (libraryLocationElement.getNodeName().equals("libraryLocation")) { //$NON-NLS-1$
+ locations.add(getLibraryLocation(libraryLocationElement));
+ }
+ }
+ }
+ vm.setLibraryLocations(locations.toArray(new IPath[locations.size()]));
+ }
+
+ private static void importLegacyInterpreters(Element config, VMDefinitionsContainer container) {
IVMInstallType vmType = RubyRuntime.getVMInstallType("org.rubypeople.rdt.launching.StandardVMType");
-
// Traverse the parsed structure and populate the VMType to VM Map
NodeList list = config.getChildNodes();
int length = list.getLength();
@@ -378,17 +512,18 @@
if (type == Node.ELEMENT_NODE) {
Element vmElement = (Element) node;
if (vmElement.getNodeName().equalsIgnoreCase("interpreter")) { //$NON-NLS-1$
- populateVMForType(vmType, vmElement, container);
+ legacyPopulateVMForType(vmType, vmElement, container);
}
}
}
+
}
/**
* Parse the specified VM node, create a VMStandin for it, and add this to the
* specified container.
*/
- private static void populateVMForType(IVMInstallType vmType, Element vmElement, VMDefinitionsContainer container) {
+ private static void legacyPopulateVMForType(IVMInstallType vmType, Element vmElement, VMDefinitionsContainer container) {
String id= vmElement.getAttribute("name"); //$NON-NLS-1$
if (id != null) {
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <caw...@us...> - 2007-04-27 13:33:06
|
Revision: 2378
http://svn.sourceforge.net/rubyeclipse/?rev=2378&view=rev
Author: cawilliams
Date: 2007-04-27 06:33:04 -0700 (Fri, 27 Apr 2007)
Log Message:
-----------
fix missing and unused messages/UI strings
Modified Paths:
--------------
trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/preferences/PreferencesMessages.java
trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/preferences/PreferencesMessages.properties
trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/ui/PreferenceConstants.java
Modified: trunk/org.rubypeople.rdt.ui/src/org/rubypeople/rdt/internal/ui/preferences/PreferencesMessages.java
===================================================================